@@ -129,7 +129,7 @@ def clean(trace, folder, docker, attempts=10):
                          ])
                     return
             raise
-    except PermissionError as err:
+    except Exception as err:
         # possibly this is windows virus scanning?
         if attempts > 0:
             trace.writeline("clean failed.. sleeping ".format(err, attempts))
